@@ -807,6 +807,23 @@ func TestSecretAPIError(t *testing.T) {
 	validate(true, err, "", cfg, conditions, statuses, t)
 }
 
+func TestTemplateRemovedFromPayload(t *testing.T) {
+	h, _, _ := setup()
+	mimic(&h, x86OCPContentRootDir)
+
+	_, filePath, doUpsert, updateCfgOnly, err := h.prepSamplesWatchEvent("template", "no-longer-exists", map[string]string{}, false)
+	switch {
+	case len(filePath) > 0:
+		t.Fatalf("should not have returned a file path")
+	case doUpsert:
+		t.Fatalf("do upsert should not be true")
+	case updateCfgOnly:
+		t.Fatalf("update cfg only should not be true")
+	case err != nil:
+		t.Fatalf("got unexpected err %s", err.Error())
+	}
+}
+
 func TestImageStreamRemovedFromPayloadWithProgressingErrors(t *testing.T) {
 	h, cfg, _ := setup()
 	mimic(&h, x86OCPContentRootDir)
@@ -864,6 +881,26 @@ func TestImageStreamRemovedFromPayloadWithProgressingErrors(t *testing.T) {
 
 }
 
+func TestImageStreamCreateErrorDegradedReason(t *testing.T) {
+	err := kerrors.NewServiceUnavailable("BadService")
+	h, cfg, event := setup()
+	mimic(&h, x86OCPContentRootDir)
+	fakeisclient := h.imageclientwrapper.(*fakeImageStreamClientWrapper)
+	fakeisclient.geterrors = map[string]error{"foo": err}
+
+	// fake out the fact the creds are there, so we can zero in
+	// on the API server error.
+	h.GoodConditionUpdate(cfg, corev1.ConditionTrue, v1.ImportCredentialsExist)
+	h.secretclientwrapper.(*fakeSecretClientWrapper).err = nil
+
+	h.Handle(event)
+	_, reason := util.AnyConditionUnknown(cfg)
+	if reason != "APIServerServiceUnavailableError" {
+		t.Fatalf("unexpected reason %s", reason)
+	}
+
+}
+
 func TestImageGetError(t *testing.T) {
 	errors := []error{
 		fmt.Errorf("getstreamerror"),
@@ -1266,6 +1303,10 @@ func TestBadSubDirList(t *testing.T) {
 	err := h.Handle(event)
 	statuses := []corev1.ConditionStatus{corev1.ConditionUnknown, corev1.ConditionTrue, corev1.ConditionTrue, corev1.ConditionFalse, corev1.ConditionFalse, corev1.ConditionFalse, corev1.ConditionFalse}
 	validate(false, err, "badsubdir", cfg, conditions, statuses, t)
+	_, reason := util.AnyConditionUnknown(cfg)
+	if reason != "FileSystemError" {
+		t.Fatalf("incorrect reason %s", reason)
+	}
 }
 
 func TestBadTopLevelStatus(t *testing.T) {
